## 0.8.0 - 2023-08-22

### Added

- [#793](https://github.com/edgarrmondragon/citric/issues/793) Implement `invite_participants` in client

### Changed

- [#617](https://github.com/edgarrmondragon/citric/issues/617) Drop support for Python 3.7

### Refactored

- [#918](https://github.com/edgarrmondragon/citric/issues/918) Use latest `typing` features where possible
- [#935](https://github.com/edgarrmondragon/citric/issues/935) Use `__all__` to expose public API

### Documentation

- [#930](https://github.com/edgarrmondragon/citric/issues/930) Update duckdb notebook example
- [#934](https://github.com/edgarrmondragon/citric/issues/934) Document integration test status in readme
- [#940](https://github.com/edgarrmondragon/citric/issues/940) Fix edit button
